@@ -5,6 +5,10 @@ from httplib2 import Http
 
 class html2data(object):
     def load(self, url=None, html=None, config={}):
+        returnObj, html = self.loadAndGetContent(url, html, config)
+        return returnObj
+    
+    def loadAndGetContent(self, url=None, html=None, config={}):
         if url:
             rest = Http()
             header, html = rest.request(url)
@@ -12,12 +16,12 @@ class html2data(object):
         tree = etree.parse(StringIO(html), parser)
         returnObj = {}
         mapping = config.get('map')
-        for key, xpath in mapping:
+        for mapping_args in mapping:
+            key = mapping_args[0]
+            xpath = mapping_args[1]
+            func = lambda x: x
+            if len(mapping_args) == 3:
+                func = mapping_args[2]
             xpath_elements = tree.xpath(xpath)
-            if(len(xpath_elements)>1):
-                returnObj[key] = []
-                for el in xpath_elements:
-                    returnObj[key].append(el.strip())
-            else:
-                returnObj[key] = xpath_elements[0].strip()
-        return returnObj
\ No newline at end of file
+            returnObj[key] = func(xpath_elements)
+        return (returnObj, html)
\ No newline at end of file
