@@ -6,7 +6,11 @@ from html2data import html2data
 class TestHtml2Data(TestCase):
     def setUp(self):
         self.handler = html2data()
-    
+    def getOne(self, elements):
+        if len(elements) >0:
+            return elements[0]
+        return None
+
     def test_load_html2xml(self):
         html = """<!DOCTYPE html><html lang="en"><head>
                 <meta charset="utf-8" />
@@ -15,16 +19,14 @@ class TestHtml2Data(TestCase):
             </head>
             <body>
                 <h1><b>Title</b></h1>
-                <div class="description">This is not a valid HTML
-            </body>
-        </html>
-        """
+                <div class="description">This is not a valid HTML</body>
+        </html>"""
         
         config = {
             'map': [
-                ['header_title', u'//head/title/text()'],
-                ['body_title', u'//h1/b/text()'],
-                ['description', u'//div[@class="description"]/text()'],
+                ['header_title', u'//head/title/text()', self.getOne],
+                ['body_title', u'//h1/b/text()', self.getOne],
+                ['description', u'//div[@class="description"]/text()', self.getOne],
             ]
         }
 
